@@ -502,7 +502,8 @@ class Gmail(object):
             response = self.service.users().messages().list(
                 userId=user_id,
                 q=query,
-                labelIds=labels_ids
+                labelIds=labels_ids,
+                includeSpamTrash=include_spam_trash
             ).execute()
 
             message_refs = []
@@ -515,6 +516,7 @@ class Gmail(object):
                     userId=user_id,
                     q=query,
                     labelIds=labels_ids,
+                    includeSpamTrash=include_spam_trash,
                     pageToken=page_token
                 ).execute()
 
@@ -637,7 +639,7 @@ class Gmail(object):
         self,
         user_id: str,
         message_ref: dict,
-        attachments: Union['ignore', 'reference', 'download'] = 'reference',
+        attachments: Union['ignore', 'reference', 'download'] = 'reference'
     ) -> Message:
         """
         Creates a Message object from a reference.
@@ -688,6 +690,7 @@ class Gmail(object):
             sender = ''
             recipient = ''
             subject = ''
+            msg_hdrs = {}
             for hdr in headers:
                 if hdr['name'] == 'Date':
                     try:
@@ -700,6 +703,8 @@ class Gmail(object):
                     recipient = hdr['value']
                 elif hdr['name'] == 'Subject':
                     subject = hdr['value']
+                
+                msg_hdrs[hdr['name']] = hdr['value']
 
             parts = self._evaluate_message_payload(
                 payload, user_id, message_ref['id'], attachments
@@ -727,7 +732,7 @@ class Gmail(object):
 
             return Message(self.service, user_id, msg_id, thread_id, recipient, 
                 sender, subject, date, snippet, plain_msg, html_msg, label_ids,
-                attms)
+                attms, msg_hdrs)
 
     def _evaluate_message_payload(
         self,
